@@ -39,7 +39,9 @@
 #define MP_T 55
 
 void mperr(const char *format, ...) __attribute__((format(printf, 1, 2)));
-void mpgcd(int *, int *);
+void mp_gcd(int64_t *, int64_t *);
 void mp_normalize(MPNumber *);
+void convert_to_radians(const MPNumber *x, MPAngleUnit unit, MPNumber *z);
+void convert_from_radians(const MPNumber *x, MPAngleUnit unit, MPNumber *z);
 
 #endif /* MP_INTERNAL_H */
